@@ -476,6 +476,10 @@ class AuthService:
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmForgotPassword, request)
 
+    def ConfirmSignup(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmSignup, request)
+
     def ForgotPassword(self, request):
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
@@ -502,6 +506,12 @@ class AuthService:
     def ConfirmForgotPasswordResponse(self, **kwargs):
         return auth_pb2.ConfirmForgotPasswordResponse(**kwargs)
 
+    def ConfirmSignupRequest(self, **kwargs):
+        return auth_pb2.ConfirmSignupRequest(**kwargs)
+
+    def ConfirmSignupResponse(self, **kwargs):
+        return auth_pb2.ConfirmSignupResponse(**kwargs)
+
     def ForgotPasswordRequest(self, **kwargs):
         return auth_pb2.ForgotPasswordRequest(**kwargs)
 
